==> marketplace-constants-0.1.4.8.tar.gz: marketplace-constants-0.1.4.8/mpconstants/regions/eo.py <==
REGIONS = {u'ad': u'Andoro',
 u'ae': u'Unui\u011dintaj Arabaj Emirlandoj',
 u'af': u'Afganujo',
 u'ag': u'Antigvo kaj Barbudo',
 u'ai': u'Angvilo',
 u'al': u'Albanujo',
 u'am': u'Armenujo',
 u'an': u'Nederlandaj Antiloj',
 u'ao': u'Angolo',
 u'aq': u'Antarkto',
 u'ar': u'Argentino',
 u'as': u'Usona Samoo',
 u'at': u'A\u016dstrujo',
 u'au': u'A\u016dstralio',
 u'aw': u'Arubo',
 u'ax': u'Alando',
 u'az': u'Azerbaj\u011dano',
 u'ba': u'Bosnujo and Hercegovino',
 u'bb': u'Barbado',
 u'bd': u'Banglade\u015do',
 u'be': u'Belgujo',
 u'bf': u'Burkino',
 u'bg': u'Bulgarujo',
 u'bh': u'Barejno',
 u'bi': u'Burundo',
 u'bj': u'Benino',
 u'bl': u'Saint Barth\xe9lemy',
 u'bm': u'Bermudoj',
 u'bn': u'Brunejo',
 u'bo': u'Bolivio',
 u'br': u'Brazilo',
 u'bs': u'Bahamoj',
 u'bt': u'Butano',
 u'bv': u'Buvetinsulo',
 u'bw': u'Bocvano',
 u'by': u'Belorusujo',
 u'bz': u'Belizo',
 u'ca': u'Kanado',
 u'cc': u'Kokosinsulo',
 u'cd': u'Kongo (Kin\u015dasa)',
 u'cf': u'Centr-Afriko',
 u'cg': u'Kongo (Brazavila)',
 u'ch': u'Svislando',
 u'ci': u'Ebur-Bordo',
 u'ck': u'Kukinsuloj',
 u'cl': u'\u0108ilio',
 u'cm': u'Kameruno',
 u'cn': u'\u0108inujo',
 u'co': u'Kolombio',
 u'cr': u'Kostariko',
 u'cu': u'Kubo',
 u'cv': u'Kaboverdo',
 u'cx': u'Kristnaskinsulo',
 u'cy': u'Kipro',
 u'cz': u'\u0108e\u0125ujo',
 u'de': u'Germanujo',
 u'dj': u'\u011cibutio',
 u'dk': u'Danujo',
 u'dm': u'Dominiko',
 u'do': u'Dominika Respubliko',
 u'dz': u'Al\u011derio',
 u'ec': u'Ekvadoro',
 u'ee': u'Estonujo',
 u'eg': u'Egiptujo',
 u'eh': u'Okcidenta Saharo',
 u'er': u'Eritreo',
 u'es': u'Hispanujo',
 u'et': u'Etiopujo',
 u'fi': u'Finnlando',
 u'fj': u'Fi\u011dio',
 u'fk': u'Falklandoj (Malvinas)',
 u'fm': u'Micronesio',
 u'fo': u'Ferooj',
 u'fr': u'Francujo',
 u'ga': u'Gabono',
 u'gb': u'Britujo',
 u'gd': u'Grenado',
 u'ge': u'Kartvelujo',
 u'gf': u'Franca Gviano',
 u'gg': u'Guernsey',
 u'gh': u'Ganao',
 u'gi': u'\u011cibraltaro',
 u'gl': u'Gronlando',
 u'gm': u'Gambio',
 u'gn': u'Guinea',
 u'gp': u'Gvadelupo',
 u'gq': u'Ekvatora Gvineo',
 u'gr': u'Grekujo',
 u'gs': u'Sud-Georgio kaj Sud-Sandvi\u0109insuloj',
 u'gt': u'Gvatemalo',
 u'gu': u'Gvamo',
 u'gw': u'Gvineo-Bisa\u016do',
 u'gy': u'Gujano',
 u'hk': u'Honkongo',
 u'hm': u'Herda kaj Makdonaldaj Insuloj',
 u'hn': u'Honduro',
 u'hr': u'Kroatujo',
 u'ht': u'Haitio',
 u'hu': u'Hungarujo',
 u'id': u'Indonezio',
 u'ie': u'Irlando',
 u'il': u'Israelo',
 u'im': u'Isle of Man',
 u'in': u'Barato',
 u'io': u'Brita Hindoceana Teritorio',
 u'iq': u'Irako',
 u'ir': u'Irano',
 u'is': u'Islando',
 u'it': u'Italujo',
 u'je': u'Jersey',
 u'jm': u'Jamajko',
 u'jo': u'Jordanio',
 u'jp': u'Japanujo',
 u'ke': u'Kenjo',
 u'kg': u'Kirgizujo',
 u'kh': u'Kambo\u011do',
 u'ki': u'Kiribato',
 u'km': u'Komoroj',
 u'kn': u'Sankta Kristoforo kaj Neviso',
 u'kp': u'Nord-Koreujo',
 u'kr': u'Sud-Koreujo',
 u'kw': u'Kuvajto',
 u'ky': u'Kejmanoj',
 u'kz': u'Kaza\u0125ujo',
 u'la': u'Laoso',
 u'lb': u'Libano',
 u'lc': u'Sankta Lucio',
 u'li': u'Li\u0125ten\u015dtejno',
 u'lk': u'Srilanko',
 u'lr': u'Liberia',
 u'ls': u'Lesoto',
 u'lt': u'Litovujo',
 u'lu': u'Luksemburgo',
 u'lv': u'Latvujo',
 u'ly': u'Libio',
 u'ma': u'Maroko',
 u'mc': u'Monako',
 u'md': u'Moldavujo',
 u'me': u'Montenegro',
 u'mf': u'Saint Martin',
 u'mg': u'Madagaskaro',
 u'mh': u'Mar\u015daloj',
 u'mk': u'Makedonujo',
 u'ml': u'Malio',
 u'mm': u'Birmo',
 u'mn': u'Mongolujo',
 u'mo': u'Makao',
 u'mp': u'Nord-Marianoj',
 u'mq': u'Martiniko',
 u'mr': u'Ma\u016dritanio',
 u'ms': u'Moncerato',
 u'mt': u'Malto',
 u'mu': u'Ma\u016dricio',
 u'mv': u'Maldivoj',
 u'mw': u'Malavio',
 u'mx': u'Meksiko',
 u'my': u'Malajzio',
 u'mz': u'Mozambiko',
 u'na': u'Namibio',
 u'nc': u'Nov-Kaledonio',
 u'ne': u'Ni\u011dero',
 u'nf': u'Norfolkinsulo',
 u'ng': u'Ni\u011deria',
 u'ni': u'Nikaragvo',
 u'nl': u'Nederlando',
 u'no': u'Norvegujo',
 u'np': u'Nepalo',
 u'nr': u'Nauro',
 u'nu': u'Niuo',
 u'nz': u'Nov-Zelando',
 u'om': u'Omano',
 u'pa': u'Panamo',
 u'pe': u'Peruo',
 u'pf': u'Franca Polinezio',
 u'pg': u'Papuo-Nov-Gvineo',
 u'ph': u'Filipinoj',
 u'pk': u'Pakistano',
 u'pl': u'Pollando',
 u'pm': u'Sankta Piero kaj Mikelono',
 u'pn': u'Pitkarna Insulo',
 u'pr': u'Puertoriko',
 u'ps': u'Palestinaj Teritorioj ("Okupaciita Palestina Teritorio")',
 u'pt': u'Portugalujo',
 u'pw': u'Pala\u016do',
 u'py': u'Paragvajo',
 u'qa': u'Kataro',
 u're': u'Reunio',
 u'ro': u'Rumanujo',
 u'rs': u'Serbujo',
 u'ru': u'Rusujo',
 u'rw': u'Ruando',
 u'sa': u'Sa\u016dda Arabujo',
 u'sb': u'Salomonoj',
 u'sc': u'Sej\u015deloj',
 u'sd': u'Sudano',
 u'se': u'Svedujo',
 u'sg': u'Singapuro',
 u'sh': u'Sankta Heleno',
 u'si': u'Slovenujo',
 u'sj': u'Svalbardo kaj Janmajeno',
 u'sk': u'Slovakujo',
 u'sl': u'Sieraleono',
 u'sm': u'Sanmarino',
 u'sn': u'Senegalo',
 u'so': u'Somalujo',
 u'sr': u'Surinamo',
 u'st': u'Santomeo kaj Principeo',
 u'sv': u'Salvadoro',
 u'sy': u'Sirio',
 u'sz': u'Svazilando',
 u'tc': u'Turkoj kaj Kajkoj',
 u'td': u'\u0108ado',
 u'tf': u'Francaj Sudaj Teritorioj',
 u'tg': u'Togolando',
 u'th': u'Tajlando',
 u'tj': u'Ta\u011dikujo',
 u'tk': u'Tokelao',
 u'tl': u'Orienta Timoro',
 u'tm': u'Turkmenujo',
 u'tn': u'Tunizio',
 u'to': u'Tongo',
 u'tr': u'Turkujo',
 u'tt': u'Trinidado kaj Tobago',
 u'tv': u'Tuvalo',
 u'tw': u'Tajvano',
 u'tz': u'Tanzanio',
 u'ua': u'Ukrainujo',
 u'ug': u'Ugando',
 u'um': u'Usonaj malgrandaj insuloj',
 u'us': u'Usono',
 u'uy': u'Urugvajo',
 u'uz': u'Uzbekujo',
 u'va': u'Vatikano',
 u'vc': u'Sankta Vicento kaj Grenadinoj',
 u've': u'Venezuelo',
 u'vg': u'Britaj Virgulinsuloj',
 u'vi': u'Usonaj Virgulinsuloj',
 u'vn': u'Vjetnamujo',
 u'vu': u'Vanuatuo',
 u'wf': u'Valiso kaj Futuno',
 u'ws': u'Samoo',
 u'ye': u'Jemeno',
 u'yt': u'Majoto',
 u'za': u'Sud-Afriko',
 u'zm': u'Zambio',
 u'zw': u'Zimbabvo'}

==> marketplace-constants-0.3.0.tar.gz: marketplace-constants-0.3.0/mpconstants/regions/eo.py <==
REGIONS = {u'ad': u'Andoro',
 u'ae': u'Unui\u011dintaj Arabaj Emirlandoj',
 u'af': u'Afganujo',
 u'ag': u'Antigvo kaj Barbudo',
 u'ai': u'Angvilo',
 u'al': u'Albanujo',
 u'am': u'Armenujo',
 u'an': u'Nederlandaj Antiloj',
 u'ao': u'Angolo',
 u'aq': u'Antarkto',
 u'ar': u'Argentino',
 u'as': u'Usona Samoo',
 u'at': u'A\u016dstrujo',
 u'au': u'A\u016dstralio',
 u'aw': u'Arubo',
 u'ax': u'Alando',
 u'az': u'Azerbaj\u011dano',
 u'ba': u'Bosnujo and Hercegovino',
 u'bb': u'Barbado',
 u'bd': u'Banglade\u015do',
 u'be': u'Belgujo',
 u'bf': u'Burkino',
 u'bg': u'Bulgarujo',
 u'bh': u'Barejno',
 u'bi': u'Burundo',
 u'bj': u'Benino',
 u'bl': u'Saint Barth\xe9lemy',
 u'bm': u'Bermudoj',
 u'bn': u'Brunejo',
 u'bo': u'Bolivio',
 u'br': u'Brazilo',
 u'bs': u'Bahamoj',
 u'bt': u'Butano',
 u'bv': u'Buvetinsulo',
 u'bw': u'Bocvano',
 u'by': u'Belorusujo',
 u'bz': u'Belizo',
 u'ca': u'Kanado',
 u'cc': u'Kokosinsulo',
 u'cd': u'Kongo (Kin\u015dasa)',
 u'cf': u'Centr-Afriko',
 u'cg': u'Kongo (Brazavila)',
 u'ch': u'Svislando',
 u'ci': u'Ebur-Bordo',
 u'ck': u'Kukinsuloj',
 u'cl': u'\u0108ilio',
 u'cm': u'Kameruno',
 u'cn': u'\u0108inujo',
 u'co': u'Kolombio',
 u'cr': u'Kostariko',
 u'cu': u'Kubo',
 u'cv': u'Kaboverdo',
 u'cx': u'Kristnaskinsulo',
 u'cy': u'Kipro',
 u'cz': u'\u0108e\u0125ujo',
 u'de': u'Germanujo',
 u'dj': u'\u011cibutio',
 u'dk': u'Danujo',
 u'dm': u'Dominiko',
 u'do': u'Dominika Respubliko',
 u'dz': u'Al\u011derio',
 u'ec': u'Ekvadoro',
 u'ee': u'Estonujo',
 u'eg': u'Egiptujo',
 u'eh': u'Okcidenta Saharo',
 u'er': u'Eritreo',
 u'es': u'Hispanujo',
 u'et': u'Etiopujo',
 u'fi': u'Finnlando',
 u'fj': u'Fi\u011dio',
 u'fk': u'Falklandoj (Malvinas)',
 u'fm': u'Micronesio',
 u'fo': u'Ferooj',
 u'fr': u'Francujo',
 u'ga': u'Gabono',
 u'gb': u'Britujo',
 u'gd': u'Grenado',
 u'ge': u'Kartvelujo',
 u'gf': u'Franca Gviano',
 u'gg': u'Guernsey',
 u'gh': u'Ganao',
 u'gi': u'\u011cibraltaro',
 u'gl': u'Gronlando',
 u'gm': u'Gambio',
 u'gn': u'Guinea',
 u'gp': u'Gvadelupo',
 u'gq': u'Ekvatora Gvineo',
 u'gr': u'Grekujo',
 u'gs': u'Sud-Georgio kaj Sud-Sandvi\u0109insuloj',
 u'gt': u'Gvatemalo',
 u'gu': u'Gvamo',
 u'gw': u'Gvineo-Bisa\u016do',
 u'gy': u'Gujano',
 u'hk': u'Honkongo',
 u'hm': u'Herda kaj Makdonaldaj Insuloj',
 u'hn': u'Honduro',
 u'hr': u'Kroatujo',
 u'ht': u'Haitio',
 u'hu': u'Hungarujo',
 u'id': u'Indonezio',
 u'ie': u'Irlando',
 u'il': u'Israelo',
 u'im': u'Isle of Man',
 u'in': u'Barato',
 u'io': u'Brita Hindoceana Teritorio',
 u'iq': u'Irako',
 u'ir': u'Irano',
 u'is': u'Islando',
 u'it': u'Italujo',
 u'je': u'Jersey',
 u'jm': u'Jamajko',
 u'jo': u'Jordanio',
 u'jp': u'Japanujo',
 u'ke': u'Kenjo',
 u'kg': u'Kirgizujo',
 u'kh': u'Kambo\u011do',
 u'ki': u'Kiribato',
 u'km': u'Komoroj',
 u'kn': u'Sankta Kristoforo kaj Neviso',
 u'kp': u'Nord-Koreujo',
 u'kr': u'Sud-Koreujo',
 u'kw': u'Kuvajto',
 u'ky': u'Kejmanoj',
 u'kz': u'Kaza\u0125ujo',
 u'la': u'Laoso',
 u'lb': u'Libano',
 u'lc': u'Sankta Lucio',
 u'li': u'Li\u0125ten\u015dtejno',
 u'lk': u'Srilanko',
 u'lr': u'Liberia',
 u'ls': u'Lesoto',
 u'lt': u'Litovujo',
 u'lu': u'Luksemburgo',
 u'lv': u'Latvujo',
 u'ly': u'Libio',
 u'ma': u'Maroko',
 u'mc': u'Monako',
 u'md': u'Moldavujo',
 u'me': u'Montenegro',
 u'mf': u'Saint Martin',
 u'mg': u'Madagaskaro',
 u'mh': u'Mar\u015daloj',
 u'mk': u'Makedonujo',
 u'ml': u'Malio',
 u'mm': u'Birmo',
 u'mn': u'Mongolujo',
 u'mo': u'Makao',
 u'mp': u'Nord-Marianoj',
 u'mq': u'Martiniko',
 u'mr': u'Ma\u016dritanio',
 u'ms': u'Moncerato',
 u'mt': u'Malto',
 u'mu': u'Ma\u016dricio',
 u'mv': u'Maldivoj',
 u'mw': u'Malavio',
 u'mx': u'Meksiko',
 u'my': u'Malajzio',
 u'mz': u'Mozambiko',
 u'na': u'Namibio',
 u'nc': u'Nov-Kaledonio',
 u'ne': u'Ni\u011dero',
 u'nf': u'Norfolkinsulo',
 u'ng': u'Ni\u011deria',
 u'ni': u'Nikaragvo',
 u'nl': u'Nederlando',
 u'no': u'Norvegujo',
 u'np': u'Nepalo',
 u'nr': u'Nauro',
 u'nu': u'Niuo',
 u'nz': u'Nov-Zelando',
 u'om': u'Omano',
 u'pa': u'Panamo',
 u'pe': u'Peruo',
 u'pf': u'Franca Polinezio',
 u'pg': u'Papuo-Nov-Gvineo',
 u'ph': u'Filipinoj',
 u'pk': u'Pakistano',
 u'pl': u'Pollando',
 u'pm': u'Sankta Piero kaj Mikelono',
 u'pn': u'Pitkarna Insulo',
 u'pr': u'Puertoriko',
 u'ps': u'Palestinaj Teritorioj (Okupaciita Palestina Teritorio)',
 u'pt': u'Portugalujo',
 u'pw': u'Pala\u016do',
 u'py': u'Paragvajo',
 u'qa': u'Kataro',
 u're': u'Reunio',
 u'ro': u'Rumanujo',
 u'rs': u'Serbujo',
 u'ru': u'Rusujo',
 u'rw': u'Ruando',
 u'sa': u'Sa\u016dda Arabujo',
 u'sb': u'Salomonoj',
 u'sc': u'Sej\u015deloj',
 u'sd': u'Sudano',
 u'se': u'Svedujo',
 u'sg': u'Singapuro',
 u'sh': u'Sankta Heleno',
 u'si': u'Slovenujo',
 u'sj': u'Svalbardo kaj Janmajeno',
 u'sk': u'Slovakujo',
 u'sl': u'Sieraleono',
 u'sm': u'Sanmarino',
 u'sn': u'Senegalo',
 u'so': u'Somalujo',
 u'sr': u'Surinamo',
 u'st': u'Santomeo kaj Principeo',
 u'sv': u'Salvadoro',
 u'sy': u'Sirio',
 u'sz': u'Svazilando',
 u'tc': u'Turkoj kaj Kajkoj',
 u'td': u'\u0108ado',
 u'tf': u'Francaj Sudaj Teritorioj',
 u'tg': u'Togolando',
 u'th': u'Tajlando',
 u'tj': u'Ta\u011dikujo',
 u'tk': u'Tokelao',
 u'tl': u'Orienta Timoro',
 u'tm': u'Turkmenujo',
 u'tn': u'Tunizio',
 u'to': u'Tongo',
 u'tr': u'Turkujo',
 u'tt': u'Trinidado kaj Tobago',
 u'tv': u'Tuvalo',
 u'tw': u'Tajvano',
 u'tz': u'Tanzanio',
 u'ua': u'Ukrainujo',
 u'ug': u'Ugando',
 u'um': u'Usonaj malgrandaj insuloj',
 u'us': u'Usono',
 u'uy': u'Urugvajo',
 u'uz': u'Uzbekujo',
 u'va': u'Vatikano',
 u'vc': u'Sankta Vicento kaj Grenadinoj',
 u've': u'Venezuelo',
 u'vg': u'Britaj Virgulinsuloj',
 u'vi': u'Usonaj Virgulinsuloj',
 u'vn': u'Vjetnamujo',
 u'vu': u'Vanuatuo',
 u'wf': u'Valiso kaj Futuno',
 u'ws': u'Samoo',
 u'ye': u'Jemeno',
 u'yt': u'Majoto',
 u'za': u'Sud-Afriko',
 u'zm': u'Zambio',
 u'zw': u'Zimbabvo'}
